﻿using System.Net;
using System.Windows;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Drawing;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.Styles;
using ThinkGeo.MapSuite.Wpf;

namespace _9210
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        string GoogleKey = "";
        string BingKey = "";

        private void map_Loaded(object sender, RoutedEventArgs e)
        {
            map.MapUnit = GeographyUnit.Meter;

            GoogleMapsOverlay g = new GoogleMapsOverlay();
            g.SendingWebRequest += Overlay_SendingWebRequest;
            map.Overlays.Add(g);

            LayerOverlay overlay = new LayerOverlay();
            InMemoryFeatureLayer layer = new InMemoryFeatureLayer();
            layer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColors.Blue, 3, true);
            layer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            LineShape line = new LineShape("LINESTRING(-10811768.9420579 4216029.49086015,-10811764.1647556 4215417.99616341,-10811888.3746159 4215413.21886109,-10811888.3746159 4215203.01755909,-10811520.5223374 4215212.57216372,-10811525.2996397 4216082.04118565)");
            layer.InternalFeatures.Add(new Feature(line));

            overlay.Layers.Add(layer);
            map.Overlays.Add(overlay);

            map.CurrentExtent = new RectangleShape(-10813202.1327534, 4216421.22965024, -10809456.7277359, 4213736.38574738);
            map.Refresh();
        }

        private void Overlay_SendingWebRequest(object sender, SendingWebRequestEventArgs e)
        {
            e.WebRequest = WebRequest.Create(e.WebRequest.RequestUri + "&key=" + GoogleKey);
        }

        private void google_Click(object sender, RoutedEventArgs e)
        {
            GoogleMapsOverlay g = new GoogleMapsOverlay();
            g.SendingWebRequest += Overlay_SendingWebRequest;
            map.Overlays.RemoveAt(0);
            map.Overlays.Add(g);
            map.Overlays.MoveTo(g, 0);

            map.ZoomLevelSet = new GoogleMapsZoomLevelSet();
            map.Refresh();
        }

        private void bing_Click(object sender, RoutedEventArgs e)
        {
            BingMapsOverlay bing = new BingMapsOverlay(BingKey, ThinkGeo.MapSuite.Wpf.BingMapsMapType.Aerial);
            map.Overlays.RemoveAt(0);
            map.Overlays.Add(bing);
            map.Overlays.MoveTo(bing, 0);

            map.ZoomLevelSet = new BingMapsZoomLevelSet();
            map.Refresh();
        }
    }
}
